Index: tcptls.c
===================================================================
--- tcptls.c	(revision 1260)
+++ tcptls.c	(working copy)
@@ -549,7 +549,13 @@
 		goto client_start_error;
 	}
 
-	if (ast_connect(desc->accept_fd, &desc->remote_address)) {
+	if (!tcptls_session->stream) {
+		/* We shouldn't be here if stream is not allocated */
+		ast_assert(0);
+		goto client_start_error;
+	}
+
+	if (ast_connect(ast_iostream_get_fd(tcptls_session->stream), &desc->remote_address)) {
 		ast_log(LOG_ERROR, "Unable to connect %s to %s: %s\n",
 			desc->name,
 			ast_sockaddr_stringify(&desc->remote_address),
@@ -557,7 +563,7 @@
 		goto client_start_error;
 	}
 
-	ast_fd_clear_flags(desc->accept_fd, O_NONBLOCK);
+	ast_fd_clear_flags(ast_iostream_get_fd(tcptls_session->stream), O_NONBLOCK);
 
 	if (desc->tls_cfg) {
 		desc->tls_cfg->enabled = 1;
@@ -567,10 +573,6 @@
 	return handle_tcptls_connection(tcptls_session);
 
 client_start_error:
-	if (desc) {
-		close(desc->accept_fd);
-		desc->accept_fd = -1;
-	}
 	ao2_ref(tcptls_session, -1);
 	return NULL;
 
@@ -594,9 +596,9 @@
 		close(desc->accept_fd);
 	}
 
-	fd = desc->accept_fd = socket(ast_sockaddr_is_ipv6(&desc->remote_address) ?
-				      AF_INET6 : AF_INET, SOCK_STREAM, IPPROTO_TCP);
-	if (desc->accept_fd < 0) {
+	fd = socket(ast_sockaddr_is_ipv6(&desc->remote_address) ?
+		    AF_INET6 : AF_INET, SOCK_STREAM, IPPROTO_TCP);
+	if (fd < 0) {
 		ast_log(LOG_ERROR, "Unable to allocate socket for %s: %s\n",
 			desc->name, strerror(errno));
 		return NULL;
@@ -606,8 +608,8 @@
 	   originate from the desired address */
 	if (!ast_sockaddr_isnull(&desc->local_address) &&
 	    !ast_sockaddr_is_any(&desc->local_address)) {
-		setsockopt(desc->accept_fd, SOL_SOCKET, SO_REUSEADDR, &x, sizeof(x));
-		if (ast_bind(desc->accept_fd, &desc->local_address)) {
+		setsockopt(fd, SOL_SOCKET, SO_REUSEADDR, &x, sizeof(x));
+		if (ast_bind(fd, &desc->local_address)) {
 			ast_log(LOG_ERROR, "Unable to bind %s to %s: %s\n",
 				desc->name,
 				ast_sockaddr_stringify(&desc->local_address),
@@ -641,8 +643,7 @@
 	return tcptls_session;
 
 error:
-	close(desc->accept_fd);
-	desc->accept_fd = -1;
+	close(fd);
 	ao2_cleanup(tcptls_session);
 	return NULL;
 }
